@@ -18,7 +18,8 @@ common_parameters: Dict[str, Any] = {}
 
 
 def start(verbose: int = 0, listener: Listener = None, groups: List[str] = None, params: Dict[str, Any] = None,
-          threads: int = 1, suite_name: str = 'Default Test Suite', dry_run: bool = False):
+          threads: int = 1, suite_name: str = 'Default Test Suite', dry_run: bool = False, filter_by_name: str = None,
+          **kwargs):
     """
     The main function of tests start
 
@@ -36,6 +37,7 @@ def start(verbose: int = 0, listener: Listener = None, groups: List[str] = None,
     operations - disk work, network requests. Obey the GIL!
     :param dry_run: if True runs test-suite with fake function except of real tests and fixtures, can be useful to
     find out order, number of tests, params of provider etc.
+    :param filter_by_name if specified - runs only tests with name containing this parameter
     :return: None
     """
     verbose = 0 if verbose not in range(4) else verbose
@@ -46,6 +48,8 @@ def start(verbose: int = 0, listener: Listener = None, groups: List[str] = None,
     test_suite.name = suite_name
     if groups:
         test_suite.filter_groups(groups)
+    if filter_by_name:
+        test_suite.filter_tests(filter_by_name)
     # If there are no tests, then stop
     if test_suite.is_empty():
         _listener.on_empty_suite(test_suite)
@@ -146,7 +150,8 @@ def _run_test_with_provider(test, group):
             _listener.on_ignored_with_provider(test, group)
     except TypeError as e:
         if 'is not iterable' not in e.args[0]:
-            raise e
+            print(e)
+            raise
         else:
             _listener.on_ignored_with_provider(test, group)
 
@@ -161,7 +166,7 @@ def _run_all_tests_in_group(group: TestGroup):
             is_one_of_before_test_failed = _run_test_with_before_and_after(test, group, is_one_of_before_test_failed)
 
 
-def _run_test_with_before_and_after(test: TestCase, group: TestGroup, is_before_failed: bool) -> bool:
+def _run_test_with_before_and_after(test: Test, group: TestGroup, is_before_failed: bool) -> bool:
     if not is_before_failed:
         _run_before(test)
     else:
@@ -181,8 +186,17 @@ def _run_test_with_before_and_after(test: TestCase, group: TestGroup, is_before_
 
 
 def _provider_next(provider_name: str) -> Any:
-    for param in TestSuite.get_instance().providers[provider_name]():
+    iter_ = TestSuite.get_instance().providers[provider_name]()
+    for param in iter_:
         yield param
+    # If it were file at provider - try to close it
+    if hasattr(iter_, 'close'):
+        try:
+            iter_.close()
+        except Exception as ex:
+            print(ex)
+            pass
+            # explicitly ignore
 
 
 def _run_test(test: Test, group: TestGroup) -> bool:
